/*
 ## Cypress USB 3.0 Platform source file (cyfx3_u3vdscr.c)
 ## ===========================
 ##
 ##  Copyright Cypress Semiconductor Corporation, 2010-2018,
 ##  All Rights Reserved
 ##  UNPUBLISHED, LICENSED SOFTWARE.
 ##
 ##  CONFIDENTIAL AND PROPRIETARY INFORMATION
 ##  WHICH IS THE PROPERTY OF CYPRESS.
 ##
 ##  Use of this file is governed
 ##  by the license agreement included in the file
 ##
 ##     <install>/license/license.txt
 ##
 ##  where <install> is the Cypress software
 ##  installation root directory path.
 ##
 ## ===========================
*/

/* This file contains the USB enumeration descriptors for the U3V (in memory) application example.
 * The descriptor arrays must be 32 byte aligned and multiple of 32 bytes if the D-cache is
 * turned on. If the linker used is not capable of supporting the aligned feature for this,
 * either the descriptors must be placed in a different section and the section should be
 * 32 byte aligned and 32 byte multiple; or dynamically allocated buffer allocated using
 * CyU3PDmaBufferAlloc must be used, and the descriptor must be loaded into it. The example
 * assumes that the aligned attribute for 32 bytes is supported by the linker. Do not add
 * any other variables to this file other than USB descriptors. This is not the only
 * pre-requisite to enabling the D-cache. Refer to the documentation for
 * CyU3PDeviceCacheControl for more information.
 */

#include "usb3vision.h"




#define SS_CFG_DSCR_NUM_INTERFACES (2)
#define SS_CFG_DSCR_LEN (0x5E)




#define CY_U3V_DEI_ENBL              (0)

/* Standard device descriptor for USB 3.0 */
const uint8_t CyU3vUSB30DeviceDscr[] __attribute__ ((aligned (32))) =
    {
        0x12,                           /* Descriptor size */
        CY_U3P_USB_DEVICE_DESCR,        /* Device descriptor type */
        0x10,0x03,                      /* USB 3.1 */
        0xEF,                           /* Device class */
        0x02,                           /* Device Sub-class */
        0x01,                           /* Device protocol */
        0x09,                           /* Maxpacket size for EP0 : 2^9 */
        0xB4,0x04,                      /* Vendor ID */
        0x01,0x10,                      /* Product ID */
        0x00,0x00,                      /* Device release number */
        0x01,                           /* Manufacture string index */
        0x02,                           /* Product string index */
        0x00,                           /* Serial number string index */
        0x01                            /* Number of configurations */
};

/* Standard device descriptor */
const uint8_t CyU3vUSB20DeviceDscr[] __attribute__ ((aligned (32))) =
    {
        0x12,                           /* Descriptor size */
        CY_U3P_USB_DEVICE_DESCR,        /* Device descriptor type */
        0x10,0x02,                      /* USB 2.10 */
        0xEF,                           /* Device class */
        0x02,                           /* Device sub-class */
        0x01,                           /* Device protocol */
        0x40,                           /* Maxpacket size for EP0 : 64 bytes */
        0xB4,0x04,                      /* Vendor ID */
        0x01,0x10,                      /* Product ID */
        0x00,0x00,                      /* Device release number */
        0x01,                           /* Manufacture string index */
        0x02,                           /* Product string index */
        0x00,                           /* Serial number string index */
        0x01                            /* Number of configurations */
};

/* Binary device object store descriptor */
const uint8_t CyU3vUSBBOSDscr[] __attribute__ ((aligned (32))) =
    {
        0x05,                           /* Descriptor size */
        CY_U3P_BOS_DESCR,               /* Device descriptor type */
        0x16,0x00,                      /* Length of this descriptor and all sub descriptors */
        0x02,                           /* Number of device capability descriptors */

        /* USB 2.0 Extension */
        0x07,                           /* Descriptor size */
        CY_U3P_DEVICE_CAPB_DESCR,       /* Device capability type descriptor */
        CY_U3P_USB2_EXTN_CAPB_TYPE,     /* USB 2.0 extension capability type */
        0x1E,0x64,0x00,0x00,            /* Supported device level features: LPM support, BESL supported,
                                       Baseline BESL=400 us, Deep BESL=1000 us. */

        /* SuperSpeed Device Capability */
        0x0A,                           /* Descriptor size */
        CY_U3P_DEVICE_CAPB_DESCR,       /* Device capability type descriptor */
        CY_U3P_SS_USB_CAPB_TYPE,        /* SuperSpeed device capability type */
        0x00,                           /* Supported device level features  */
        0x0E,0x00,                      /* Speeds supported by the device : SS, HS and FS */
        0x03,                           /* Functionality support */
        0x0A,                           /* U1 device exit latency */
        0xFF,0x07                       /* U2 device exit latency */
};

/* Standard device qualifier descriptor */
const uint8_t CyU3vUSBDeviceQualDscr[] __attribute__ ((aligned (32))) =
    {
        0x0A,                           /* descriptor size */
        CY_U3P_USB_DEVQUAL_DESCR,       /* Device qualifier descriptor type */
        0x00,0x02,                      /* USB 2.0 */
        0xEF,                           /* Device class */
        0x02,                           /* Device sub-class */
        0x01,                           /* Device protocol */
        0x40,                           /* Maxpacket size for EP0 : 64 bytes */
        0x01,                           /* Number of configurations */
        0x00                            /* Reserved */
};

/* Standard super speed configuration descriptor */
const uint8_t CyU3vUSBSSConfigDscr[] __attribute__ ((aligned (32))) =
    {
        /* Configuration descriptor */
        0x09,                           /* Descriptor size */
        CY_U3P_USB_CONFIG_DESCR,        /* Configuration descriptor type */

#if CY_U3V_DEI_ENBL
        0x74,0x00,                      /* Length of this descriptor and all sub descriptors */
        0x03,                           /* Number of interfaces */
#else
        0x5E,0x00,             /* Total Length of Report Descriptor */
        SS_CFG_DSCR_NUM_INTERFACES,                           /* Number of interfaces */
#endif
        0x01,                           /* Configuration number */
        0x07,                           /* Configuration string index */
        0x80,                           /* Config characteristics - Bus powered */
        0x32,                           /* Max power consumption of device (in 8mA unit) : 400mA */

        /* Interface association descriptor */
        0x08,                           /* Descriptor size */
        CY_U3V_INTF_ASSN_DSCR_TYPE,     /* Interface association descr type */
        0x00,                           /* I/f number of first VideoControl i/f */

#if CY_U3V_DEI_ENBL
        0x03,                           /* Number of video streaming i/f */
#else
        0x02,                           /* Number of video streaming i/f */
#endif

        0xEF,                           /* Miscellaneous Class */
        0x05,                           /* USB3 Vision */
        0x00,                           /* Protocol : Not used */
        0x03,                           /* String desc index for interface */

        /* Device control interface descriptor */
        0x09,                           /* Descriptor size */
        CY_U3P_USB_INTRFC_DESCR,        /* Interface descriptor type */
        0x00,                           /* Interface number */
        0x00,                           /* Alternate setting number */
        0x02,                           /* Number of end points */
        0xEF,                           /* Miscellaneous class */
        0x05,                           /* USB3 Vision */
        0x00,                           /* Protocol : Device Control */
        0x00,                           /* Interface descriptor string index */

        /* Class specific device info descriptor */
        0x14,          		    /* Descriptor Size */
        0x24,			    /* Descriptor type = U3V_INTERFACE */
        0x01,			    /* Descriptor Subtype = U3V_DEVICEINFO */
        0x00, 0x00, 0x01, 0x00,	    /* GenCP Version */
        0x00, 0x00, 0x01, 0x00,                         /* U3V Version */
        0x04,			    /* U3V GUID String index */
        0x01,			    /* Vendor Name String index */
        0x02,			    /* Model Name String index */
        0x05,			    /* Family Name String index */
        0x06,			    /* Device Version String index */
        0x00,			    /* Manufacturer info string index */
        0x00,			    /* Serial Number string index */
        0x00,			    /* User Defined Name string index */
        0x0C,			    /* USB Speed Support - SS and HS supported */

        /* Video control status endpoint descriptor */
        0x07,                           /* Descriptor size */
        CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
        CY_U3V_EP_DCI_CMD,               /* Endpoint address and description */
        CY_U3P_USB_EP_BULK,             /* Bulk end point type */
        0x00,0x04,                      /* Max packet size = 1024 bytes */
        0x00,                           /* Servicing interval */

        /* Super speed endpoint companion descriptor */
        0x06,                           /* Descriptor size */
        CY_U3P_SS_EP_COMPN_DESCR,       /* SS endpoint companion descriptor type */
        0x00,                           /* Max no. of packets in a Burst : 1 */
        0x00,                           /* Mult: Max number of packets : 1 */
        0x00, 0x00,                     /* Bytes per interval : N/A */

        /* Video control status endpoint descriptor */
        0x07,                           /* Descriptor size */
        CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
        CY_U3V_EP_DCI_RSP,               /* Endpoint address and description */
        CY_U3P_USB_EP_BULK,             /* Bulk end point type */
        0x00,0x04,                      /* Max packet size = 1024 bytes */
        0x00,                           /* Servicing interval */

        /* Super speed endpoint companion descriptor */
        0x06,                           /* Descriptor size */
        CY_U3P_SS_EP_COMPN_DESCR,       /* SS endpoint companion descriptor type */
        0x00,                           /* Max no. of packets in a Burst : 1 */
        0x00,                           /* Mult: Max number of packets : 1 */
        0x00, 0x00,                     /* Bytes per interval : N/A */

#if CY_U3V_DEI_ENBL
        /* Device Event Interface Descriptor */
        0x09,			    /* Descriptor size */
        CY_U3P_USB_INTRFC_DESCR,	    /* Interface Descriptor Type */
        0x01,			    /* Interface Number */
        0x00,			    /* Alternate Setting */
        0x01,			    /* Number of Endpoints */
        0xEF,			    /* Miscellaneous Class */
        0x05,			    /* USB3 Vision */
        0x01,			    /* Device Events */
        0x00,			    /* Interface String index */

        /* Endpoint descriptor */
        0x07,			    /* Descriptor size */
        CY_U3P_USB_ENDPNT_DESCR,	    /* Endpoint descriptor type */
        CY_FX_EP_DEI_EVENT,		    /* bEndpoint Address */
        CY_U3P_USB_EP_BULK,		    /* bmAttributes */
        0x00, 0x04,			    /* wMaxPacketSize */
        0x00,			    /* bInterval */

        /* SS Endpoint Companion Descriptor */
        0x06,			    /* Descriptor size */
        CY_U3P_SS_EP_COMPN_DESCR,	    /* EP Companion descriptor type */
        0x00,			    /* bMaxBurst */
        0x00,			    /* bmAttributes */
        0x00, 0x00,			    /* wBytesPerInterval */
#endif

        /* Device Streaming Interface Descriptor */
        0x09,			    /* Descriptor size */
        CY_U3P_USB_INTRFC_DESCR,	    /* Interface Descriptor Type */

#if CY_U3V_DEI_ENBL
        0x02,			    /* Interface Number */
#else
        0x01,               /* Interface Number */
#endif

        0x00,			    /* Alternate Setting */
        0x01,			    /* Number of Endpoints */
        0xEF,			    /* Miscellaneous Class */
        0x05,			    /* USB3 Vision */
        0x02,			    /* Device Streaming */
        0x00,			    /* Interface String index */

        /* Endpoint descriptor for streaming video data */
        0x07,                           /* Descriptor size */
        CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
        CY_U3V_EP_DSI_STREAM,            /* Endpoint address and description */
        CY_U3P_USB_EP_BULK,             /* Bulk End Point */
        0x00, 0x04,                     /* Maximum packet size. */
        0x00,                           /* Servicing interval for data transfers */

        /* Super speed endpoint companion descriptor */
        0x06,                           /* Descriptor size */
        CY_U3P_SS_EP_COMPN_DESCR,       /* SS endpoint companion descriptor type */
        (CY_FX_STREAM_EP_BURST-1),     /* Max no. of packets in a Burst : 8 */
        0x00,                           /* Mult.: Max number of packets : 1 */
        0x00,0x00                 	/* Field Valid only for Periodic Endpoints */





};

/* Standard High Speed Configuration Descriptor */
const uint8_t CyU3vUSBHSConfigDscr[] __attribute__ ((aligned (32))) =
    {
        /* Configuration descriptor */
        0x09,                           /* Descriptor size */
        CY_U3P_USB_CONFIG_DESCR,        /* Configuration descriptor type */

#if CY_U3V_DEI_ENBL
        0x5C,0x00,                      /* Length of this descriptor and all sub descriptors */
        0x03,                           /* Number of interfaces */
#else
        0xA0,0x00,                      /* Length of this descriptor and all sub descriptors */
        0x05,                           /* Number of interfaces */
#endif
        0x01,                           /* Configuration number */
        0x08,                           /* Configuration string index */
        0x80,                           /* Config characteristics - bus powered */
        0xC8,                           /* Max power consumption of device (in 2mA unit) : 400mA */

        /* Interface association descriptor */
        0x08,                           /* Descriptor size */
        CY_U3V_INTF_ASSN_DSCR_TYPE,     /* Interface association descr type */
        0x00,                           /* I/f number of first video control i/f */

#ifdef CY_U3V_DEI_ENBL
        0x03,                           /* Number of video streaming i/f */
#else
        0x02,                           /* Number of video streaming i/f */
#endif

        0xEF,                           /* Miscellaneous Class */
        0x05,                           /* USB3Vision Class */
        0x00,                           /* Protocol : not used */
        0x03,                           /* String desc index for interface */

        /* Device control interface descriptor */
        0x09,                           /* Descriptor size */
        CY_U3P_USB_INTRFC_DESCR,        /* Interface descriptor type */
        0x00,                           /* Interface number */
        0x00,                           /* Alternate setting number */
        0x02,                           /* Number of end points */
        0xEF,                           /* Miscellaneous class */
        0x05,                           /* USB3Vision sub class */
        0x00,                           /* Interface protocol code */
        0x00,                           /* Interface descriptor string index */


        /* Class specific device info descriptor */
        0x14,          		    /* Descriptor Size */
        0x24,			    /* Descriptor type = U3V_INTERFACE */
        0x01,			    /* Descriptor Subtype = U3V_DEVICEINFO */
        0x00, 0x00, 0x01, 0x00,	    /* GenCP Version */
        0x00, 0x00, 0x01, 0x00,	    /* U3V Version */
        0x04,			    /* U3V GUID String index */
        0x01,			    /* Vendor Name String index */
        0x02,			    /* Model Name String index */
        0x05,			    /* Family Name String index */
        0x06,			    /* Device Version String index */
        0x00,			    /* Manufacturer info string index */
        0x00,			    /* Serial Number string index */
        0x00,			    /* User Defined Name string index */
        0x0C,			    /* USB Speed Support - SS and HS supported */

        /* endpoint descriptor : Command */
        0x07,                           /* Descriptor size */
        CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
        CY_U3V_EP_DCI_CMD,               /* Endpoint address and description */
        CY_U3P_USB_EP_BULK,             /* Interrupt end point type */
        0x00,0x02,                      /* Max packet size = 512 bytes */
        0x00,                           /* Servicing interval : NA */

        /* endpoint descriptor : Response */
        0x07,                           /* Descriptor size */
        CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
        CY_U3V_EP_DCI_RSP,               /* Endpoint address and description */
        CY_U3P_USB_EP_BULK,             /* Interrupt end point type */
        0x00,0x02,                      /* Max packet size = 512 bytes */
        0x00,                           /* Servicing interval : NA */

#if CY_U3V_DEI_ENBL
        /* Device Event Interface Descriptor */
        0x09,			    /* Descriptor size */
        CY_U3P_USB_INTRFC_DESCR,	    /* Interface Descriptor Type */
        0x01,			    /* Interface Number */
        0x00,			    /* Alternate Setting */
        0x01,			    /* Number of Endpoints */
        0xEF,			    /* Miscellaneous Class */
        0x05,			    /* USB3 Vision */
        0x01,			    /* Device Events */
        0x00,			    /* Interface String index */

        /* Endpoint descriptor */
        0x07,			    /* Descriptor size */
        CY_U3P_USB_ENDPNT_DESCR,	    /* Endpoint descriptor type */
        CY_FX_EP_DEI_EVENT,		    /* bEndpoint Address */
        CY_U3P_USB_EP_BULK,		    /* bmAttributes */
        0x00, 0x04,			    /* wMaxPacketSize */
        0x00,			    /* bInterval */
#endif

        /* Device Streaming Interface Descriptor */
        0x09,			    /* Descriptor size */
        CY_U3P_USB_INTRFC_DESCR,	    /* Interface Descriptor Type */

#if CY_U3V_DEI_ENBL
        0x02,			    /* Interface Number */
#else
        0x01,
#endif

        0x00,			    /* Alternate Setting */
        0x01,			    /* Number of Endpoints */
        0xEF,			    /* Miscellaneous Class */
        0x05,			    /* USB3 Vision */
        0x02,			    /* Device Streaming */
        0x00,			    /* Interface String index */

        /* Endpoint descriptor for streaming video data */
        0x07,                           /* Descriptor size */
        CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
        CY_U3V_EP_DSI_STREAM,            /* Endpoint address and description */
        CY_U3P_USB_EP_BULK,             /* Bulk End Point */
        0x00, 0x02,                     /* Maximum packet size. */
        0x00                          /* Servicing interval for data transfers */


};

/* Dummy Full Speed Configuration Descriptor*/
const uint8_t CyU3vUsbFSConfigDscr[] =
    {
        /* Configuration descriptor */
        0x09,                               /* Descriptor size */
        CY_U3P_USB_CONFIG_DESCR,            /* Configuration descriptor type */
#ifdef CX3_UVC_1_0_SUPPORT
        0xEB,0x00,                          /* Length of this descriptor and all sub descriptors */
#else
        0xEC,0x00,                          /* Length of this descriptor and all sub descriptors */
#endif
        0x02,                               /* Number of interfaces */
        0x01,                               /* Configuration number */
        0x05,                               /* Configuration string index */
        0xC0,                               /* Config characteristics - self powered */
        0x32                                /* Max power consumption of device (in 2mA unit) : 100mA */
};

/* Standard language ID string descriptor */
const uint8_t CyU3vUSBStringLangIDDscr[] __attribute__ ((aligned (32))) =
    {
        0x04,                           /* Descriptor size */
        CY_U3P_USB_STRING_DESCR,        /* Device descriptor type */
        0x09,0x04                       /* Language ID supported */
};

/* Standard manufacturer string descriptor */
const uint8_t CyU3vManufactureDscr[] __attribute__ ((aligned (32))) =
    {
        0x10,                           /* Descriptor size */
        CY_U3P_USB_STRING_DESCR,        /* Device descriptor type */
        'C',0x00,
        'y',0x00,
        'p',0x00,
        'r',0x00,
        'e',0x00,
        's',0x00,
        's',0x00
};

/* Standard product string descriptor */
const uint8_t CyU3vProductDscr[] __attribute__ ((aligned (32))) =
    {
        0x08,                           /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,        /* Device descriptor type */
        'F',0x00,
        'X',0x00,
        '3',0x00
};

/* Function string descriptor */
const uint8_t CyU3vFunctionDscr[] __attribute__ ((aligned (32))) =
    {
        0x26,                           /* Descriptor size */
        CY_U3P_USB_STRING_DESCR,        /* Device descriptor type */
        'U',0x00,
        'S',0x00,
        'B',0x00,
        '3',0x00,
        ' ',0x00,
        'V',0x00,
        'i',0x00,
        's',0x00,
        'i',0x00,
        'o',0x00,
        'n',0x00,
        ' ',0x00,
        'D',0x00,
        'e',0x00,
        'v',0x00,
        'i',0x00,
        'c',0x00,
        'e',0x00
};

/* Standard GUID string descriptor */
const uint8_t CyU3vGUIDDscr[] __attribute__ ((aligned (32))) =
    {
        0x1A,                           /* Descriptor size */
        CY_U3P_USB_STRING_DESCR,        /* Device descriptor type */
        '0',0x00,
        '4',0x00,
        'B',0x00,
        '4',0x00,
        '4',0x00,
        '3',0x00,
        '2',0x00,
        '1',0x00,
        '5',0x00,
        '6',0x00,
        '7',0x00,
        '8',0x00
};

/* Family Name String Descriptor */
const uint8_t CyU3vFamilyNameDscr[] __attribute__ ((aligned (32))) =
    {
        0x0E,
        CY_U3P_USB_STRING_DESCR,
        'E',0x00,
        'Z',0x00,
        '-',0x00,
        'U',0x00,
        'S',0x00,
        'B',0x00
};


/* Device Version String Descriptor */
const uint8_t CyU3vDeviceVerDscr[] __attribute__ ((aligned (32))) =
    {
        0x0C,
        CY_U3P_USB_STRING_DESCR,
        'R',0x00,
        'E',0x00,
        'V',0x00,
        '-',0x00,
        'C',0x00
};

/* SS Configuration string descriptor */
const uint8_t CyU3vConfigSSDscr[] __attribute__ ((aligned (32))) =
    {
        0x10,                               /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,            /* Device descriptor type */
        'U', 0x00,                          /* Super-Speed Configuration Descriptor */
        'S', 0x00,
        'B', 0x00,
        '-', 0x00,
        '3', 0x00,
        '.', 0x00,
        '0', 0x00
};
/*  HS Configuration string descriptor */
const uint8_t CyU3vConfigHSDscr[]  __attribute__ ((aligned (32))) =
    {
        0x10,                               /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,            /* Device descriptor type */
        'U', 0x00,                          /* High-Speed Configuration Descriptor */
        'S', 0x00,
        'B', 0x00,
        '-', 0x00,
        '2', 0x00,
        '.', 0x00,
        '1', 0x00
};



/* [ ] */

